@@ -4,7 +4,9 @@ from ubai_client.apis import SearchApi
 from ubai_client.models import ArtifactStorage
 from time import sleep
 from utf_queue_client.scripts import setup_telemetry
+from otel_extensions import instrumented
 from retry import retry
+from opentelemetry import trace
 
 
 @click.command()
@@ -32,7 +34,6 @@ def cli(
     retries: int = 6,
 ):
     with setup_telemetry():
-        search_api = SearchApi()
         metadata_dict = {}
         for key, value in metadata:
             metadata_dict[key] = value
@@ -46,11 +47,24 @@ def cli(
 
         @retry(Exception, delay=3, backoff=2, max_delay=12, tries=retries + 1)
         def retry_wrapper():
-            search_results = search_api.find_all_artifacts(search_opts)
-            return [result.id for result in search_results]
+            return find_all_artifacts(search_opts)
 
         return retry_wrapper()
 
 
+@instrumented
+def find_all_artifacts(search_opts: ArtifactStorage):
+    search_api = SearchApi()
+    span = trace.get_current_span()
+    span.set_attribute("artifact.name", search_opts.name or "")
+    span.set_attribute("artifact.extension", search_opts.extension or "")
+    for key in search_opts.metadata:
+        span.set_attribute(f"metadata.{key}", search_opts.metadata[key])
+    search_results = search_api.find_all_artifacts(search_opts)
+    result_ids = [result.id for result in search_results]
+    span.set_attribute("search_results", result_ids)
+    return result_ids
+
+
 if __name__ == "__main__":
     cli_entrypoint()
